"""django-moat"""

VERSION = (0, 1, 1)

__version__ = ".".join(map(str, VERSION[0:3])) + "".join(VERSION[3:])
__author__ = "Andy Mroczkowski"
__contact__ = "andy@mrox.net"
__homepage__ = "http://amrox.github.com/django-moat/"
__docformat__ = "restructuredtext"
# __license__ = "BSD (3 clause)"
